@@ -2,9 +2,11 @@
 mutate.tbl_svy <- function(
   .data,
   ...,
+  .by = NULL,
   .keep = c("all", "used", "unused", "none"),
   .before = NULL,
-  .after = NULL
+  .after = NULL,
+  .unpack = TRUE
 ) {
   dots <- rlang::quos(...)
 
@@ -12,6 +14,13 @@ mutate.tbl_svy <- function(
     stop("Cannot modify survey variable")
   }
 
+  .by <- rlang::enquo(.by)
+  # Can't just pass `.by` to dplyr because we need to calculate survey statistics per group
+  if (!rlang::quo_is_null(.by)) {
+    .data <- group_by(.data, !!.by)
+    return(mutate(.data, !!!dots, .keep = .keep, .before = {{.before}}, .after = {{.after}}, .unpack = .unpack))
+  }
+
   # Set current_svy so available to svy stat functions
   old <- set_current_svy(list(full = .data, split = split_for_context(.data)))
   on.exit(set_current_svy(old), add = TRUE)
@@ -24,6 +33,7 @@ mutate.tbl_svy <- function(
     .after = {{.after}}
   )
 
+  if (.unpack && !is_lazy_svy(.data)) .data$variables <- unpack_cols(.data$variables)
   .data
 }
 
@@ -64,8 +74,7 @@ rename.tbl_svy <- function(.data, ...) {
 #' @importFrom tidyselect everything
 #' @export
 rename_with.tbl_svy <- function(.data, .fn, .cols = everything(), ...) {
-  dots <- rlang::quos(...)
-  .data$variables <- rename_with(.data$variables, .fn = .fn, .cols = {{.cols}}, !!!dots)
+  .data$variables <- rename_with(.data$variables, .fn = .fn, .cols = {{.cols}}, ...)
 
   .data
 }
